R

Struct R 

pub struct R(/* private fields */);
Register CTRL reader

Implementations

Source

impl R

pub fn edgesel(&self) -> EDGESEL_R

Bits 3:4 - This field controls which edges on the comparator output set the COMPEDGE bit (bit 23 below):

pub fn compsa(&self) -> COMPSA_R

Bit 6 - Comparator output control

pub fn comp_vp_sel(&self) -> COMP_VP_SEL_R

Bits 8:10 - Selects positive voltage input

pub fn comp_vm_sel(&self) -> COMP_VM_SEL_R

Bits 11:13 - Selects negative voltage input

pub fn edgeclr(&self) -> EDGECLR_R

Bit 20 - Interrupt clear bit. To clear the COMPEDGE bit and thus negate the interrupt request, toggle the EDGECLR bit by first writing a 1 and then a 0.

pub fn compstat(&self) -> COMPSTAT_R

Bit 21 - Comparator status. This bit reflects the state of the comparator output.

pub fn compedge(&self) -> COMPEDGE_R

Bit 23 - Comparator edge-detect status.

pub fn intena(&self) -> INTENA_R

Bit 24 - Must be set to generate interrupts.

pub fn hys(&self) -> HYS_R

Bits 25:26 - Controls the hysteresis of the comparator. When the comparator is outputting a certain state, this is the difference between the selected signals, in the opposite direction from the state being output, that will switch the output.

Methods from Deref<Target = R<CTRL_SPEC>>

pub fn bits(&self) -> REG::Ux

Reads raw bits from register.