pub struct W(/* private fields */);Expand description
Register CTRL writer
Implementations
Sourceimpl W
impl W
Sourcepub fn edgesel(&mut self) -> EDGESEL_W<'_>
pub fn edgesel(&mut self) -> EDGESEL_W<'_>
Bits 3:4 - This field controls which edges on the comparator output set the COMPEDGE bit (bit 23 below):
Sourcepub fn comp_vp_sel(&mut self) -> COMP_VP_SEL_W<'_>
pub fn comp_vp_sel(&mut self) -> COMP_VP_SEL_W<'_>
Bits 8:10 - Selects positive voltage input
Sourcepub fn comp_vm_sel(&mut self) -> COMP_VM_SEL_W<'_>
pub fn comp_vm_sel(&mut self) -> COMP_VM_SEL_W<'_>
Bits 11:13 - Selects negative voltage input
Sourcepub fn edgeclr(&mut self) -> EDGECLR_W<'_>
pub fn edgeclr(&mut self) -> EDGECLR_W<'_>
Bit 20 - Interrupt clear bit. To clear the COMPEDGE bit and thus negate the interrupt request, toggle the EDGECLR bit by first writing a 1 and then a 0.
Sourcepub fn compstat(&mut self) -> COMPSTAT_W<'_>
pub fn compstat(&mut self) -> COMPSTAT_W<'_>
Bit 21 - Comparator status. This bit reflects the state of the comparator output.
Sourcepub fn compedge(&mut self) -> COMPEDGE_W<'_>
pub fn compedge(&mut self) -> COMPEDGE_W<'_>
Bit 23 - Comparator edge-detect status.