pub struct LPWRMODE_R(/* private fields */);Expand description
Field LPWRMODE reader - The low-power ADC mode
Implementations
Sourceimpl LPWRMODE_R
impl LPWRMODE_R
Sourcepub fn variant(&self) -> LPWRMODE_A
pub fn variant(&self) -> LPWRMODE_A
Get enumerated values variant
Sourcepub fn is_lpwrmode_0(&self) -> bool
pub fn is_lpwrmode_0(&self) -> bool
Checks if the value of the field is LPWRMODE_0
Sourcepub fn is_lpwrmode_1(&self) -> bool
pub fn is_lpwrmode_1(&self) -> bool
Checks if the value of the field is LPWRMODE_1
Methods from Deref<Target = FieldReader<bool, LPWRMODE_A>>