pub struct MODE_R(/* private fields */);Expand description
Field MODE reader - Indicates whether the primary method for retrieving conversion results for this sequence will be accomplished via reading the global data register (SEQA_GDAT) at the end of each conversion, or the individual channel result registers at the end of the entire sequence. Impacts when conversion-complete interrupt/DMA trigger for sequence-A will be generated and which overrun conditions contribute to an overrun interrupt as described below.
Implementations
Methods from Deref<Target = FieldReader<bool, MODE_A>>