#[repr(u8)]pub enum TYPE_A {
TYPE_0 = 0,
TYPE_1 = 1,
TYPE_2 = 2,
TYPE_3 = 3,
}Expand description
Selects type of Touch arrangement to use and so how to handle XPINSEL bits
Value on reset: 0
Variants
TYPE_0 = 0
0: Normal - all X elements are treated as normal, such as buttons and sliders.
TYPE_1 = 1
1: 3x3 grid using NXP Complementary measurements. The 1st 9 Xs are assumed to be the 3x3 grid. After that would be normal X elements. This will also allow 3x1 and 3x2 Note: Only possible if XMAX in STATUS is >=8
TYPE_2 = 2
2: 5 Sensors interleaved to act as 3x3 touch area using NXP Complementary measurements. 1st 5 Xs used for this, all remaining are treated as normal. Note that if 16 X pins allowed, the 16th will not be usable when TYPE=1. (use TYPE=0 and select 1 smaller than 15 ( and any others from 1 smaller than 5 on up in XPINSEL).
TYPE_3 = 3
3: 9 Sensors interleaved to act as 5x5 touch area using NXP Complementary measurements. 1st 9 Xs used for this, all remaining are treated as normal. Note: Only possible if XMAX in STATUS is >=8