FDIV_R

Struct FDIV_R 

pub struct FDIV_R(/* private fields */);
Field FDIV reader - Functional clock divider, or 0 if no divide. The term “clocks” in this spec then refer to divided clocks. For a 12MHz input (e.g. FRO 12MHz), this would normally be set to generate a 4MHz output (so, 2). For a 1MHz input, it should be 0. Note for internal use: this does not produce a 50/50 duty cycle when non even divide.

Implementations

Source

impl FDIV_R

pub fn variant(&self) -> Option<FDIV_A>

Get enumerated values variant

pub fn is_fdiv_0(&self) -> bool

Checks if the value of the field is FDIV_0

pub fn is_fdiv_1(&self) -> bool

Checks if the value of the field is FDIV_1

pub fn is_fdiv_2(&self) -> bool

Checks if the value of the field is FDIV_2

pub fn is_fdiv_3(&self) -> bool

Checks if the value of the field is FDIV_3

pub fn is_fdiv_4(&self) -> bool

Checks if the value of the field is FDIV_4

pub fn is_fdiv_5(&self) -> bool

Checks if the value of the field is FDIV_5

pub fn is_fdiv_7(&self) -> bool

Checks if the value of the field is FDIV_7

pub fn is_fdiv_8(&self) -> bool

Checks if the value of the field is FDIV_8

pub fn is_fdiv_9(&self) -> bool

Checks if the value of the field is FDIV_9

pub fn is_fdiv_10(&self) -> bool

Checks if the value of the field is FDIV_10

pub fn is_fdiv_11(&self) -> bool

Checks if the value of the field is FDIV_11

pub fn is_fdiv_12(&self) -> bool

Checks if the value of the field is FDIV_12

pub fn is_fdiv_13(&self) -> bool

Checks if the value of the field is FDIV_13

pub fn is_fdiv_14(&self) -> bool

Checks if the value of the field is FDIV_14

pub fn is_fdiv_15(&self) -> bool

Checks if the value of the field is FDIV_15

Methods from Deref<Target = FieldReader<u8, FDIV_A>>

pub fn bits(&self) -> U

Reads raw bits from field.