POLLMODE_R

Struct POLLMODE_R 

pub struct POLLMODE_R(/* private fields */);
Field POLLMODE reader - Mode of operation. May only change from 0 to another value. So, if 2 or 3, must be changed to 0 1st. Any attempt to go from non-0 to non-0 will result in 0 anyway.

Implementations

Source

impl POLLMODE_R

pub fn variant(&self) -> POLLMODE_A

Get enumerated values variant

pub fn is_none(&self) -> bool

Checks if the value of the field is NONE

pub fn is_poll_now(&self) -> bool

Checks if the value of the field is POLL_NOW

pub fn is_normal(&self) -> bool

Checks if the value of the field is NORMAL

pub fn is_low_power_mode(&self) -> bool

Checks if the value of the field is LOW_POWER_MODE

Methods from Deref<Target = FieldReader<u8, POLLMODE_A>>

pub fn bits(&self) -> U

Reads raw bits from field.