pub struct WAIT_R(/* private fields */);Expand description
Field WAIT reader - If 0, the block will continue its X based measurements, even if the TOUCH register has not been read (and so could OVERRUN). If 1, it will wait until read when a touch (TOUCH’s ISTOUCH bit is set) before starting the next. This should not normally be needed.
Methods from Deref<Target = FieldReader<bool, bool>>