pub struct WAIT_W<'a> { /* private fields */ }Expand description
Field WAIT writer - If 0, the block will continue its X based measurements, even if the TOUCH register has not been read (and so could OVERRUN). If 1, it will wait until read when a touch (TOUCH’s ISTOUCH bit is set) before starting the next. This should not normally be needed.
Implementations