pub struct R(/* private fields */);Expand description
Register FMSSTOP reader
Implementations
Sourceimpl R
impl R
Sourcepub fn stopa(&self) -> STOPA_R
pub fn stopa(&self) -> STOPA_R
Bits 0:16 - Stop address for signature generation (the word specified by STOP is included in the address range). The address is in units of memory words, not bytes.
Sourcepub fn strtbist(&self) -> STRTBIST_R
pub fn strtbist(&self) -> STRTBIST_R
Bit 31 - When this bit is written to 1, signature generation starts. At the end of signature generation, this bit is automatically cleared.
Methods from Deref<Target = R<FMSSTOP_SPEC>>