RegisterBlock

Struct RegisterBlock 

#[repr(C)]
pub struct RegisterBlock {
Show 13 fields pub isel: Reg<ISEL_SPEC>, pub ienr: Reg<IENR_SPEC>, pub sienr: Reg<SIENR_SPEC>, pub cienr: Reg<CIENR_SPEC>, pub ienf: Reg<IENF_SPEC>, pub sienf: Reg<SIENF_SPEC>, pub cienf: Reg<CIENF_SPEC>, pub rise: Reg<RISE_SPEC>, pub fall: Reg<FALL_SPEC>, pub ist: Reg<IST_SPEC>, pub pmctrl: Reg<PMCTRL_SPEC>, pub pmsrc: Reg<PMSRC_SPEC>, pub pmcfg: Reg<PMCFG_SPEC>,
}
Register block

Fields

isel: Reg<ISEL_SPEC>

0x00 - Pin Interrupt Mode register

ienr: Reg<IENR_SPEC>

0x04 - Pin interrupt level or rising edge interrupt enable register

sienr: Reg<SIENR_SPEC>

0x08 - Pin interrupt level or rising edge interrupt set register

cienr: Reg<CIENR_SPEC>

0x0c - Pin interrupt level (rising edge interrupt) clear register

ienf: Reg<IENF_SPEC>

0x10 - Pin interrupt active level or falling edge interrupt enable register

sienf: Reg<SIENF_SPEC>

0x14 - Pin interrupt active level or falling edge interrupt set register

cienf: Reg<CIENF_SPEC>

0x18 - Pin interrupt active level or falling edge interrupt clear register

rise: Reg<RISE_SPEC>

0x1c - Pin interrupt rising edge register

fall: Reg<FALL_SPEC>

0x20 - Pin interrupt falling edge register

ist: Reg<IST_SPEC>

0x24 - Pin interrupt status register

pmctrl: Reg<PMCTRL_SPEC>

0x28 - Pattern match interrupt control register

pmsrc: Reg<PMSRC_SPEC>

0x2c - Pattern match interrupt bit-slice source register

pmcfg: Reg<PMCFG_SPEC>

0x30 - Pattern match interrupt bit slice configuration register