pub enum LPOSCDPDEN_A {
DISABLED = 0,
ENABLED = 1,
}Expand description
causes the low-power oscillator to remain running during Deep power-down mode provided that bit 2 in this register is set as well. You must set this bit for the self wake-up timer to be able to wake up the part from Deep power-down mode. Remark: Do not set this bit unless you use the self wake-up timer with the low-power oscillator clock source to wake up from Deep power-down mode.
Value on reset: 0
Variants