pub struct LPOSCDPDEN_R(/* private fields */);Expand description
Field LPOSCDPDEN reader - causes the low-power oscillator to remain running during Deep power-down mode provided that bit 2 in this register is set as well. You must set this bit for the self wake-up timer to be able to wake up the part from Deep power-down mode. Remark: Do not set this bit unless you use the self wake-up timer with the low-power oscillator clock source to wake up from Deep power-down mode.
Implementations
Sourceimpl LPOSCDPDEN_R
impl LPOSCDPDEN_R
Sourcepub fn variant(&self) -> LPOSCDPDEN_A
pub fn variant(&self) -> LPOSCDPDEN_A
Get enumerated values variant
Sourcepub fn is_disabled(&self) -> bool
pub fn is_disabled(&self) -> bool
Checks if the value of the field is DISABLED
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Checks if the value of the field is ENABLED
Methods from Deref<Target = FieldReader<bool, LPOSCDPDEN_A>>