pub struct LPOSCDPDEN_W<'a> { /* private fields */ }Expand description
Field LPOSCDPDEN writer - causes the low-power oscillator to remain running during Deep power-down mode provided that bit 2 in this register is set as well. You must set this bit for the self wake-up timer to be able to wake up the part from Deep power-down mode. Remark: Do not set this bit unless you use the self wake-up timer with the low-power oscillator clock source to wake up from Deep power-down mode.
Implementations
Sourceimpl<'a> LPOSCDPDEN_W<'a>
impl<'a> LPOSCDPDEN_W<'a>
Sourcepub fn variant(self, variant: LPOSCDPDEN_A) -> &'a mut W
pub fn variant(self, variant: LPOSCDPDEN_A) -> &'a mut W
Writes variant to the field