pub struct O2RES_R(/* private fields */);Expand description
Field O2RES reader - Effect of simultaneous set and clear on output 2.
Implementations
Sourceimpl O2RES_R
impl O2RES_R
Sourcepub fn is_no_change(&self) -> bool
pub fn is_no_change(&self) -> bool
Checks if the value of the field is NO_CHANGE
Sourcepub fn is_toggle_output(&self) -> bool
pub fn is_toggle_output(&self) -> bool
Checks if the value of the field is TOGGLE_OUTPUT
Methods from Deref<Target = FieldReader<u8, O2RES_A>>