R

Struct R 

pub struct R(/* private fields */);
Register EXTTRACECMD reader

Implementations

Source

impl R

pub fn start(&self) -> START_R

Bit 0 - Trace start command. Writing a one to this bit sets the TSTART signal to the MTB to HIGH and starts tracing if the TSTARTEN bit in the MTB master register is set to one as well.

pub fn stop(&self) -> STOP_R

Bit 1 - Trace stop command. Writing a one to this bit sets the TSTOP signal in the MTB to HIGH and stops tracing if the TSTOPEN bit in the MTB master register is set to one as well.

Methods from Deref<Target = R<EXTTRACECMD_SPEC>>

pub fn bits(&self) -> REG::Ux

Reads raw bits from register.