pub struct START_R(/* private fields */);Expand description
Field START reader - Trace start command. Writing a one to this bit sets the TSTART signal to the MTB to HIGH and starts tracing if the TSTARTEN bit in the MTB master register is set to one as well.
Methods from Deref<Target = FieldReader<bool, bool>>