STOP_W

Struct STOP_W 

pub struct STOP_W<'a> { /* private fields */ }
Field STOP writer - Trace stop command. Writing a one to this bit sets the TSTOP signal in the MTB to HIGH and stops tracing if the TSTOPEN bit in the MTB master register is set to one as well.

Implementations

Source

impl<'a> STOP_W<'a>

pub fn set_bit(self) -> &'a mut W

Sets the field bit

pub fn clear_bit(self) -> &'a mut W

Clears the field bit

pub fn bit(self, value: bool) -> &'a mut W

Writes raw bits to the field