PSEL_R

Struct PSEL_R 

pub struct PSEL_R(/* private fields */);
Field PSEL reader - Post divider ratio P. The division ratio is 2 x P.

Implementations

Source

impl PSEL_R

pub fn variant(&self) -> PSEL_A

Get enumerated values variant

pub fn is_psel_0(&self) -> bool

Checks if the value of the field is PSEL_0

pub fn is_psel_1(&self) -> bool

Checks if the value of the field is PSEL_1

pub fn is_psel_2(&self) -> bool

Checks if the value of the field is PSEL_2

pub fn is_psel_3(&self) -> bool

Checks if the value of the field is PSEL_3

Methods from Deref<Target = FieldReader<u8, PSEL_A>>

pub fn bits(&self) -> U

Reads raw bits from field.