pub struct R(/* private fields */);Expand description
Register CTRL reader
Implementations
Sourceimpl R
impl R
Sourcepub fn edgesel(&self) -> EDGESEL_R
pub fn edgesel(&self) -> EDGESEL_R
Bits 3:4 - This field controls which edges on the comparator output set the COMPEDGE bit (bit 23 below):
Sourcepub fn comp_vp_sel(&self) -> COMP_VP_SEL_R
pub fn comp_vp_sel(&self) -> COMP_VP_SEL_R
Bits 8:10 - Selects positive voltage input
Sourcepub fn comp_vm_sel(&self) -> COMP_VM_SEL_R
pub fn comp_vm_sel(&self) -> COMP_VM_SEL_R
Bits 11:13 - Selects negative voltage input
Sourcepub fn edgeclr(&self) -> EDGECLR_R
pub fn edgeclr(&self) -> EDGECLR_R
Bit 20 - Interrupt clear bit. To clear the COMPEDGE bit and thus negate the interrupt request, toggle the EDGECLR bit by first writing a 1 and then a 0.
Sourcepub fn compstat(&self) -> COMPSTAT_R
pub fn compstat(&self) -> COMPSTAT_R
Bit 21 - Comparator status. This bit reflects the state of the comparator output.
Sourcepub fn compedge(&self) -> COMPEDGE_R
pub fn compedge(&self) -> COMPEDGE_R
Bit 23 - Comparator edge-detect status.