pub struct BURST_R(/* private fields */);Expand description
Field BURST reader - Writing a 1 to this bit will cause this conversion sequence to be continuously cycled through. Other sequence A triggers will be ignored while this bit is set. Repeated conversions can be halted by clearing this bit. The sequence currently in progress will be completed before conversions are terminated. Note that a new sequence could begin just before BURST is cleared.
Methods from Deref<Target = FieldReader<bool, bool>>