pub struct MODE_W<'a> { /* private fields */ }Expand description
Field MODE writer - Indicates whether the primary method for retrieving conversion results for this sequence will be accomplished via reading the global data register (SEQA_GDAT) at the end of each conversion, or the individual channel result registers at the end of the entire sequence. Impacts when conversion-complete interrupt/DMA trigger for sequence-A will be generated and which overrun conditions contribute to an overrun interrupt as described below.
Implementations
Sourceimpl<'a> MODE_W<'a>
impl<'a> MODE_W<'a>
Sourcepub fn end_of_conversion(self) -> &'a mut W
pub fn end_of_conversion(self) -> &'a mut W
End of conversion. The sequence A interrupt/DMA trigger will be set at the end of each individual ADC conversion performed under sequence A. This flag will mirror the DATAVALID bit in the SEQA_GDAT register. The OVERRUN bit in the SEQA_GDAT register will contribute to generation of an overrun interrupt/DMA trigger if enabled.
Sourcepub fn end_of_sequence(self) -> &'a mut W
pub fn end_of_sequence(self) -> &'a mut W
End of sequence. The sequence A interrupt/DMA trigger will be set when the entire set of sequence-A conversions completes. This flag will need to be explicitly cleared by software or by the DMA-clear signal in this mode. The OVERRUN bit in the SEQA_GDAT register will NOT contribute to generation of an overrun interrupt/DMA trigger since it is assumed this register may not be utilized in this mode.