#[repr(u8)]pub enum POLLMODE_A {
NONE = 0,
POLL_NOW = 1,
NORMAL = 2,
LOW_POWER_MODE = 3,
}Expand description
Mode of operation. May only change from 0 to another value. So, if 2 or 3, must be changed to 0 1st. Any attempt to go from non-0 to non-0 will result in 0 anyway.
Value on reset: 0
Variants
NONE = 0
0: None, inactive. Poll and time counters are turned off. Writing this will reset state and stop any collection in progress. Note: this has no effect on STATUS - those must be cleared manually.
POLL_NOW = 1
1: Poll now - forces a manual poll to be started immediately, using XPINSEL X pin(s) to activate in the integration loop (all pins set together). Self clears - clear is not indication it is done (see STATUS).
NORMAL = 2
2: Normal polling using poll delay from POLL_TCNT register. This will start with the poll delay (which can be 0).
LOW_POWER_MODE = 3
3: The CAPT block will operate in low-power mode. This means it will use GPIO as input, use combination touch measurements, and assume it is to wake the system. This will use the POLL_TCNT poll delay, and start with the delay.