pub struct FDIV_R(/* private fields */);Expand description
Field FDIV reader - Functional clock divider, or 0 if no divide. The term “clocks” in this spec then refer to divided clocks. For a 12MHz input (e.g. FRO 12MHz), this would normally be set to generate a 4MHz output (so, 2). For a 1MHz input, it should be 0. Note for internal use: this does not produce a 50/50 duty cycle when non even divide.
Implementations
Sourceimpl FDIV_R
impl FDIV_R
Sourcepub fn is_fdiv_10(&self) -> bool
pub fn is_fdiv_10(&self) -> bool
Checks if the value of the field is FDIV_10
Sourcepub fn is_fdiv_11(&self) -> bool
pub fn is_fdiv_11(&self) -> bool
Checks if the value of the field is FDIV_11
Sourcepub fn is_fdiv_12(&self) -> bool
pub fn is_fdiv_12(&self) -> bool
Checks if the value of the field is FDIV_12
Sourcepub fn is_fdiv_13(&self) -> bool
pub fn is_fdiv_13(&self) -> bool
Checks if the value of the field is FDIV_13
Sourcepub fn is_fdiv_14(&self) -> bool
pub fn is_fdiv_14(&self) -> bool
Checks if the value of the field is FDIV_14
Sourcepub fn is_fdiv_15(&self) -> bool
pub fn is_fdiv_15(&self) -> bool
Checks if the value of the field is FDIV_15
Methods from Deref<Target = FieldReader<u8, FDIV_A>>