pub struct POLLMODE_R(/* private fields */);Expand description
Field POLLMODE reader - Mode of operation. May only change from 0 to another value. So, if 2 or 3, must be changed to 0 1st. Any attempt to go from non-0 to non-0 will result in 0 anyway.
Implementations
Sourceimpl POLLMODE_R
impl POLLMODE_R
Sourcepub fn variant(&self) -> POLLMODE_A
pub fn variant(&self) -> POLLMODE_A
Get enumerated values variant
Sourcepub fn is_poll_now(&self) -> bool
pub fn is_poll_now(&self) -> bool
Checks if the value of the field is POLL_NOW
Sourcepub fn is_low_power_mode(&self) -> bool
pub fn is_low_power_mode(&self) -> bool
Checks if the value of the field is LOW_POWER_MODE
Methods from Deref<Target = FieldReader<u8, POLLMODE_A>>