pub struct TYPE_W<'a> { /* private fields */ }Expand description
Field TYPE writer - Selects type of Touch arrangement to use and so how to handle XPINSEL bits
Implementations
Sourceimpl<'a> TYPE_W<'a>
impl<'a> TYPE_W<'a>
Sourcepub fn type_0(self) -> &'a mut W
pub fn type_0(self) -> &'a mut W
Normal - all X elements are treated as normal, such as buttons and sliders.
Sourcepub fn type_1(self) -> &'a mut W
pub fn type_1(self) -> &'a mut W
3x3 grid using NXP Complementary measurements. The 1st 9 Xs are assumed to be the 3x3 grid. After that would be normal X elements. This will also allow 3x1 and 3x2 Note: Only possible if XMAX in STATUS is >=8
Sourcepub fn type_2(self) -> &'a mut W
pub fn type_2(self) -> &'a mut W
5 Sensors interleaved to act as 3x3 touch area using NXP Complementary measurements. 1st 5 Xs used for this, all remaining are treated as normal. Note that if 16 X pins allowed, the 16th will not be usable when TYPE=1. (use TYPE=0 and select 1 smaller than 15 ( and any others from 1 smaller than 5 on up in XPINSEL).