pub struct R(/* private fields */);Expand description
Register DPDCTRL reader
Implementations
Sourceimpl R
impl R
Sourcepub fn wakeuphys(&self) -> WAKEUPHYS_R
pub fn wakeuphys(&self) -> WAKEUPHYS_R
Bit 0 - WAKEUP pin hysteresis enable
Sourcepub fn wakepad_disable(&self) -> WAKEPAD_DISABLE_R
pub fn wakepad_disable(&self) -> WAKEPAD_DISABLE_R
Bit 1 - WAKEUP pin disable. Setting this bit disables the wake-up pin, so it can be used for other purposes. Remark: Never set this bit if you intend to use a pin to wake up the part from Deep power-down mode. You can only disable the wake-up pin if the self wake-up timer is enabled and configured. Remark: Setting this bit is not necessary if Deep power-down mode is not used.
Sourcepub fn lposcen(&self) -> LPOSCEN_R
pub fn lposcen(&self) -> LPOSCEN_R
Bit 2 - Enable the low-power oscillator for use with the 10 kHz self wake-up timer clock. You must set this bit if the CLKSEL bit in the self wake-up timer CTRL bit is set. Do not enable the low-power oscillator if the self wake-up timer is clocked by the divided IRC or the external clock input.
Sourcepub fn lposcdpden(&self) -> LPOSCDPDEN_R
pub fn lposcdpden(&self) -> LPOSCDPDEN_R
Bit 3 - causes the low-power oscillator to remain running during Deep power-down mode provided that bit 2 in this register is set as well. You must set this bit for the self wake-up timer to be able to wake up the part from Deep power-down mode. Remark: Do not set this bit unless you use the self wake-up timer with the low-power oscillator clock source to wake up from Deep power-down mode.
Sourcepub fn wakeupclkhys(&self) -> WAKEUPCLKHYS_R
pub fn wakeupclkhys(&self) -> WAKEUPCLKHYS_R
Bit 4 - External clock input for the self wake-up timer WKTCLKIN hysteresis enable.
Sourcepub fn wakeclkpad_disable(&self) -> WAKECLKPAD_DISABLE_R
pub fn wakeclkpad_disable(&self) -> WAKECLKPAD_DISABLE_R
Bit 5 - Disable the external clock input for the self-wake-up timer. Setting this bit enables the self-wake-up timer clock pin WKTCLKLIN. To minimize power consumption, especially in deep power-down mode, disable this clock input when not using the external clock option for the self-wake-up timer.
Sourcepub fn resethys(&self) -> RESETHYS_R
pub fn resethys(&self) -> RESETHYS_R
Bit 6 - RESET pin hysteresis enable.
Sourcepub fn reset_disable(&self) -> RESET_DISABLE_R
pub fn reset_disable(&self) -> RESET_DISABLE_R
Bit 7 - RESET pin disable. Setting this bit disables the reset wake-up function, so the pin can be used for other purposes. Remark: Setting this bit is not necessary if deep power-down mode is not used.