pub struct START_W<'a> { /* private fields */ }Expand description
Field START writer - Trace start command. Writing a one to this bit sets the TSTART signal to the MTB to HIGH and starts tracing if the TSTARTEN bit in the MTB master register is set to one as well.
Implementations