pub struct STOP_W<'a> { /* private fields */ }Expand description
Field STOP writer - Trace stop command. Writing a one to this bit sets the TSTOP signal in the MTB to HIGH and stops tracing if the TSTOPEN bit in the MTB master register is set to one as well.
Implementations